@@ -47,14 +47,19 @@ var appHelpTextTemplate = `{{ "NAME" | color "" "heading" }}:
   {{"-x, --reverse" | color "yellow" ""}}               Performs a DNS Lookup for an IPv4 or IPv6 address. Sets the query type and class to PTR and IN respectively.
 
 {{ "Resolver Options" | color "" "heading" }}:
-  {{"--ndots=INT" | color "yellow" ""}}        Specify ndots parameter. Takes value from /etc/resolv.conf if using the system namesever or 1 otherwise.
-  {{"--search" | color "yellow" ""}}           Use the search list defined in resolv.conf. Defaults to true. Set --search=false to disable search list.
-  {{"--timeout" | color "yellow" ""}}          Specify timeout (in seconds) for the resolver to return a response.
-  {{"-4 --ipv4" | color "yellow" ""}}          Use IPv4 only.
-  {{"-6 --ipv6" | color "yellow" ""}}          Use IPv6 only.
+  {{"--strategy=STRATEGY" | color "yellow" ""}}          Specify strategy to query nameserver listed in etc/resolv.conf. ({{"all, random, first" | color "cyan" ""}}).
+  {{"--ndots=INT" | color "yellow" ""}}                  Specify ndots parameter. Takes value from /etc/resolv.conf if using the system namesever or 1 otherwise.
+  {{"--search" | color "yellow" ""}}                     Use the search list defined in resolv.conf. Defaults to true. Set --search=false to disable search list.
+  {{"--timeout" | color "yellow" ""}}                    Specify timeout (in seconds) for the resolver to return a response.
+  {{"-4 --ipv4" | color "yellow" ""}}                    Use IPv4 only.
+  {{"-6 --ipv6" | color "yellow" ""}}                    Use IPv6 only.
+  {{"--ndots=INT" | color "yellow" ""}}                  Specify ndots parameter. Takes value from /etc/resolv.conf if using the system namesever or 1 otherwise.
+  {{"--tls-hostname=HOSTNAME" | color "yellow" ""}}      Provide a hostname for doing verification of the certificate if the provided DoT nameserver is an IP.
+  {{"--skip-hostname-verification" | color "yellow" ""}} Skip TLS Hostname Verification in case of DOT Lookups.
 
 {{ "Output Options" | color "" "heading" }}:
   {{"-J, --json " | color "yellow" ""}}                 Format the output as JSON.
+  {{"--short" | color "yellow" ""}}                     Short output format. Shows only the response section.
   {{"--color   " | color "yellow" ""}}                  Defaults to true. Set --color=false to disable colored output.
   {{"--debug " | color "yellow" ""}}                    Enable debug logging.
   {{"--time" | color "yellow" ""}}                      Shows how long the response took from the server.
